Deletes the persistent cache directory used when functions are called with
cache = TRUE (see subincomeR_cache_dir()), including the downloaded
DOSE dataset and geometries stored there.
Usage
subincomeR_cache_clear(ask = interactive())Deletes the persistent cache directory used when functions are called with
cache = TRUE (see subincomeR_cache_dir()), including the downloaded
DOSE dataset and geometries stored there.
subincomeR_cache_clear(ask = interactive())