Learn R Programming

subincomeR (version 0.6.0)

subincomeR_cache_dir: Path to the subincomeR persistent cache directory

Description

Returns the directory used to store downloaded data when getDOSE(), getDOSE_geom() or matchDOSE() are called with cache = TRUE. The location follows tools::R_user_dir(), so it respects the R_USER_CACHE_DIR environment variable. The directory is not created by this function.

Usage

subincomeR_cache_dir()

Arguments

Value

A character string with the path to the cache directory.

Examples

Run this code
subincomeR_cache_dir()

Run the code above in your browser using DataLab